@@ -29,8 +29,8 @@ def print_percent_done(index_input, total, bar_len=50, title_input='Please wait'
     done = int(round(percent_done_round / (100 / bar_len)))
     togo = bar_len - done
 
-    done_str = '█' * done
-    togo_str = '░' * togo
+    done_str = '=' * done
+    togo_str = '_' * togo
 
     sys.stdout.write(f'\r{title_input}: [{done_str}{togo_str}] {percent_done_round}% done')
 
@@ -224,7 +224,7 @@ def get_value_from_array(data_arr_input, low_li, up_li):
 def main():
     parser = argparse.ArgumentParser(prog='vinset',
                                      description='VINSET package.')
-    parser.add_argument('--version', action='version', version='2.0.6'),
+    parser.add_argument('--version', action='version', version='2.0.8'),
     parser.add_argument("-i", dest="input_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
                         help="input mp4 file", metavar="filename.mp4")
     parser.add_argument("-d", dest="input_data_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
@@ -244,6 +244,10 @@ def main():
         print("Input file name:", input_file)
     else:
         print("Input file must be mp4.")
+    if str(csv_data).endswith(".csv"):
+        print("Input data file name:", csv_data)
+    else:
+        print("Input data file must be csv.")
     if str(output_file).endswith(".mp4"):
         print("Output file name:", output_file)
     else:
